/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sundhedsdatastyrelsen.cbs.service.cache;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.SerializationFeature;
import com.fasterxml.jackson.databind.module.SimpleModule;
import dk.sundhedsdatastyrelsen.cbs.dao.PersonRecord;
import dk.sundhedsdatastyrelsen.cbs.dto.impl.kafka.DataFetcherJobImpl;
import dk.sundhedsdatastyrelsen.cbs.dto.impl.lab.LabResultImpl;
import dk.sundhedsdatastyrelsen.cbs.dto.impl.lab.LabResultsImpl;
import dk.sundhedsdatastyrelsen.cbs.dto.impl.vaccination.EffectuatedVaccinationImpl;
import dk.sundhedsdatastyrelsen.cbs.dto.impl.vaccination.VaccinationImpl;
import dk.sundhedsdatastyrelsen.cbs.dto.kafka.DataFetcherJob;
import dk.sundhedsdatastyrelsen.cbs.dto.lab.LabResult;
import dk.sundhedsdatastyrelsen.cbs.dto.lab.LabResults;
import dk.sundhedsdatastyrelsen.cbs.dto.vaccination.EffectuatedVaccination;
import dk.sundhedsdatastyrelsen.cbs.dto.vaccination.Vaccination;
import dk.sundhedsdatastyrelsen.cbs.test.CbsTest;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.BeforeAll;
import org.junit.jupiter.api.Disabled;
import org.junit.jupiter.api.Test;
import org.springframework.jdbc.core.namedparam.NamedParameterJdbcTemplate;
import org.springframework.jdbc.datasource.DriverManagerDataSource;

import java.util.Collection;
import java.util.Map;


@CbsTest
@Disabled("Requires local DB")
class DataReaderTest {

    NamedParameterJdbcTemplate jdbcTemplate = new NamedParameterJdbcTemplate(new DriverManagerDataSource("jdbc:mysql://localhost:3306/cbs-datacache", "admin", "admin"));

    static ObjectMapper objectMapper;

    @BeforeAll
    static void setUp() {
        final SimpleModule module = new SimpleModule()
            .addAbstractTypeMapping(Vaccination.class, VaccinationImpl.class)
            .addAbstractTypeMapping(EffectuatedVaccination.class, EffectuatedVaccinationImpl.class)
            .addAbstractTypeMapping(LabResults.class, LabResultsImpl.class)
            .addAbstractTypeMapping(LabResult.class, LabResultImpl.class)
            .addAbstractTypeMapping(LabResult.PcrResult.class, LabResultImpl.PcrResultImpl.class)
            .addAbstractTypeMapping(LabResult.AntigenResult.class, LabResultImpl.AntigenResultImpl.class)
            .addAbstractTypeMapping(DataFetcherJob.class, DataFetcherJobImpl.class);
        objectMapper = new ObjectMapper().findAndRegisterModules().registerModule(module).disable(SerializationFeature.WRITE_DATES_AS_TIMESTAMPS);
    }

    @Test
    void name() {
        final DataReader dataReader = new DataReader(jdbcTemplate, objectMapper, true);

        final Collection<Data> data = dataReader.getData("2502801010");

        Assertions.assertNotNull(data);
    }
}
