/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sundhedsdatastyrelsen.cbs.service.servlet;

import dk.sundhedsdatastyrelsen.cbs.datacache.liquibase.AsyncLiquibaseService;
import dk.sundhedsdatastyrelsen.cbs.datacache.status.JdbcStatusChecker;
import dk.sundhedsdatastyrelsen.cbs.kafka.CbsKafkaProducer;
import dk.sundhedsdatastyrelsen.cbs.kafka.status.KafkaStatusChecker;
import dk.sundhedsdatastyrelsen.cbs.status.CertificateStatusChecker;
import dk.sundhedsdatastyrelsen.cbs.test.CbsTest;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.mockito.Answers;
import org.mockito.Mock;
import org.springframework.context.annotation.AnnotationConfigApplicationContext;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.test.context.junit.jupiter.SpringJUnitConfig;

import javax.servlet.ServletContextEvent;

import static dk.sundhedsdatastyrelsen.cbs.service.servlet.ServiceServletContextListener.SPRING_APPLICATION_CONTEXT;
import static dk.sundhedsdatastyrelsen.cbs.service.servlet.ServiceServletContextListener.SPRING_BASE_PACKAGES_PROPERTY;
import static org.junit.jupiter.api.Assertions.assertDoesNotThrow;
import static org.mockito.Mockito.*;

@CbsTest
@SuppressWarnings("java:S5979") /*SonarLint cannot see that @CbsTest has @ExtendWith(MockitoExtension.class)*/
@SpringJUnitConfig
class ServiceServletContextListenerTest {
    @Mock(answer = Answers.RETURNS_DEEP_STUBS)
    private ServletContextEvent servletContextEvent;
    @Mock
    private AnnotationConfigApplicationContext applicationContext;
    @Mock
    private CbsKafkaProducer cbsKafkaProducer;

    @Configuration
    public static class MockConfig {
        @Bean
        CertificateStatusChecker certificateStatusChecker() {
            return mock(CertificateStatusChecker.class);
        }

        @Bean
        KafkaStatusChecker kafkaStatusChecker() {
            return mock(KafkaStatusChecker.class);
        }

        @Bean
        JdbcStatusChecker jdbcStatusChecker() {
            return mock(JdbcStatusChecker.class);
        }

        @Bean
        public AsyncLiquibaseService asyncLiquibaseService() {
            return mock(AsyncLiquibaseService.class);
        }
    }

    @BeforeEach
    void setUp() {
        when(servletContextEvent.getServletContext().getAttribute(SPRING_APPLICATION_CONTEXT)).thenReturn(applicationContext);
        when(applicationContext.getBean(CbsKafkaProducer.class)).thenReturn(cbsKafkaProducer);
    }

    @Test
    void test_app_lifecycle() {
        ServiceServletContextListener contextListener = new ServiceServletContextListener();
        System.setProperty(SPRING_BASE_PACKAGES_PROPERTY, "dk.sundhedsdatastyrelsen.cbs.service.servlet");
        assertDoesNotThrow(() -> contextListener.contextInitialized(servletContextEvent));
    }

    @Test
    void test_destroy() {
        ServiceServletContextListener contextListener = new ServiceServletContextListener();
        assertDoesNotThrow(() -> contextListener.contextDestroyed(servletContextEvent));
        verify(cbsKafkaProducer).close();
        verify(applicationContext).close();
    }
}
