/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sundhedsdatastyrelsen.cbs;

import dk.sundhedsdatastyrelsen.cbs.cbsdriver.CBSDriver;
import dk.sundhedsdatastyrelsen.cbs.configuration.IntegrationTestConfiguration;
import dk.sundhedsdatastyrelsen.cbs.webservice.idws.IdwsUser;
import org.junit.jupiter.api.Disabled;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.TestInstance;
import org.junit.jupiter.api.extension.ExtendWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.test.context.ContextConfiguration;
import org.springframework.test.context.junit.jupiter.SpringExtension;

@ExtendWith(SpringExtension.class)
@ContextConfiguration(classes = {IntegrationTestConfiguration.class})
@TestInstance(TestInstance.Lifecycle.PER_CLASS)
@Disabled("Useful when developing")
class ManualITCase {

    @Autowired
    private CBSDriver cbsDriver;

    @Test
    void testGetCoronaPasses_same_cpr_x_times() {
        for (int i = 0; i < 10; i++) {
            testGetCoronaPasses();
        }
    }

    @Test
    void testGetCoronaPasses_all_cpr() {
        for (IdwsUser user : IdwsUser.values()) {
            System.out.println(user.cpr());
            cbsDriver.getCoronaPass(user);
        }
    }

    @Test
    void testGetCoronaPasses() {
        /*
          DDV test1
          2401010010: Pas ej OK {"vaccinationStatus":"DELVIST_VACCINERET","documentId":"N/A","personInfo":{"personNameStructure":{"personGivenName":"Trine","personMiddleName":null,"personSurnameName":"Jørgensen"},"personCivilRegistrationIdentifier":"2401010010"},"vaccinationAgainst":"SARS-CoV-2 (COVID-19)","effectuation":[{"drugName":"Pfizer BioNTech Covid-19 vacc","effectuatedDateTime":"2021-01-24T23:00:00.000+0000","vaccine":{"vaccineIdentifier":32115515736,"vaccineName":"Pfizer BioNTech Covid-19 vacc","disease":[{"diseaseIdentifier":32115515735,"diseaseName":"Covid-19","diseaseNameDK":"Covid-19 sygdom","atc":{"code":"J07BX","text":"Andre virale vacciner"}}],"atc":{"code":"J07BX","text":"Andre virale vacciner"},"vaccineKeywordsText":"","displayMinimumVaccinationPlan":[],"ssidrug":[]},"ssidrug":{"atc":{"code":null,"text":null},"drugIdentifier":32115514735,"drugName":"Pfizer BioNTech COVID-19 Vacc","drugForm":{"drugFormCode":null,"drugFormText":"injektionsvæske, suspension"},"drugStrength":{"content":[{"name":"{http://vaccinationsregister.dk/schemas/2013/12/01}DrugStrengthText","declaredType":"java.lang.String","scope":"dk.vaccinationsregister.schemas._2013._12._01.DrugStrengthType","value":"","nil":false,"globalScope":false,"typeSubstituted":false}]}}}],"vaccinationPassportAsPDF":null}
          2401010011: Pas ej OK, der er kun givet 1 vaccination
          2401010012: Pas OK (Moderna) {"vaccinationStatus":"VACCINERET","documentId":"1000110","personInfo":{"personNameStructure":{"personGivenName":"Ina","personMiddleName":null,"personSurnameName":"Kristensen"},"personCivilRegistrationIdentifier":"2401010012"},"vaccinationAgainst":"SARS-CoV-2 (COVID-19)","effectuation":[{"drugName":"Moderna Covid-19 Vaccine","effectuatedDateTime":"2021-03-22T08:04:00.000+0000","vaccine":{"vaccineIdentifier":32115518136,"vaccineName":"Moderna Covid-19 Vaccine","disease":[{"diseaseIdentifier":32115515735,"diseaseName":"Covid-19","diseaseNameDK":"Covid-19 sygdom","atc":{"code":"J07BX","text":"Andre virale vacciner"}}],"atc":{"code":"J07BX","text":"Andre virale vacciner"},"vaccineKeywordsText":"","displayMinimumVaccinationPlan":[],"ssidrug":[]},"ssidrug":{"atc":{"code":null,"text":null},"drugIdentifier":32115518135,"drugName":"Moderna Covid-19 vaccine","drugForm":{"drugFormCode":null,"drugFormText":"injektionsvæske, suspension"},"drugStrength":{"content":[]}}},{"drugName":"Moderna Covid-19 Vaccine","effectuatedDateTime":"2021-04-24T07:04:00.000+0000","vaccine":{"vaccineIdentifier":32115518136,"vaccineName":"Moderna Covid-19 Vaccine","disease":[{"diseaseIdentifier":32115515735,"diseaseName":"Covid-19","diseaseNameDK":"Covid-19 sygdom","atc":{"code":"J07BX","text":"Andre virale vacciner"}}],"atc":{"code":"J07BX","text":"Andre virale vacciner"},"vaccineKeywordsText":"","displayMinimumVaccinationPlan":[],"ssidrug":[]},"ssidrug":{"atc":{"code":null,"text":null},"drugIdentifier":32115518135,"drugName":"Moderna Covid-19 vaccine","drugForm":{"drugFormCode":null,"drugFormText":"injektionsvæske, suspension"},"drugStrength":{"content":[]}}}],"vaccinationPassportAsPDF":null}
          2401010013: Pas OK (Pfizer)
          2401010014: Pas ej OK (min.interval ikke overholdt)
          2401010015: Pas ej OK (kun 1 vaccination)
          2401010016: Pas OK (Pfizer)
          2401010017: Pas OK (Pfizer)
          2401010018: Pas OK (krydsforløb med AstraZeneca + Moderna)

          insert-kids-data.sql (note that '2401010010' has no data):
          (person_identifier, test_identifier, type_of_test, test_name, test_manufacturer, timestamp_sample, timestamp_result, result_of_the_test, testing_centre_or_facility, timestamp_last_update, sletteflag)
          ('2401010011', 2021001016099, 'SARS2', '', '', '2021-01-12 10:29:00', '2021-01-12 20:19:00', 'NEGATIV', '', '2021-04-22 03:51:37', 0),
          ('2401010012', 2021010110318, 'SARS2', '', '', '2021-03-11 09:15:00', '2021-04-23 10:40:00', 'NEGATIV', '', '2021-04-23 11:23:40', 0),
          ('2401010012', 2021013666631, 'SARSG', '', '', '2021-02-20 10:30:00', '2021-02-20 10:50:00', 'POSITIV', 'CAPA Biotech Aps', '2021-04-23 11:27:13', 0),
          ('2401010013', 2021013966213, 'SARSG', '', '', '2021-03-23 07:09:00', '2021-03-23 07:29:00', 'POSITIV', 'CAPA Biotech Aps', '2021-04-23 11:27:13', 0),
          ('2401010014', 2021013966258, 'SARSG', '', '', '2021-03-23 08:06:00', '2021-03-23 08:26:00', 'POSITIV', 'CAPA Biotech Aps', '2021-04-23 11:27:13', 0),
          ('2401010015', 2021016153907, 'SARSG', '', '', '2021-03-31 16:40:00', '2021-03-31 17:00:00', 'POSITIV', 'CAPA Biotech Aps', '2021-04-23 11:27:13', 0),
          ('2401010016', 2021017448428, 'SARS2', '', '', '2021-04-05 08:00:00', '2021-04-05 18:36:00', 'NEGATIV', '', '2021-04-23 12:24:43', 0),
          ('2401010017', 2021017561852, 'SARSG', '', '', '2021-04-05 17:50:00', '2021-04-05 18:10:00', 'POSITIV', 'CAPA Biotech Aps', '2021-04-23 11:27:13', 0),
          ('2401010018', 2021018005363, 'SARSG', '', '', '2021-04-06 10:55:00', '2021-04-06 11:15:00', 'NEGATIV', 'SEI kommunal- og skoleindberetninger ', '2021-04-22 14:57:34', 0),
          ('2401010018', 2021018005364, 'SARSG', '', '', '2021-04-06 10:36:00', '2021-04-06 10:56:00', 'NEGATIV', 'SEI kommunal- og skoleindberetninger ', '2021-04-22 14:57:34', 0),

            0508018967 (gyldigt testpas)
            0101859568 (gyldig immunitet)
            0601830299 (gyldig vaccination)
         */

        cbsDriver.getCoronaPass(IdwsUser.NC_CPR_1202363235);
    }


}
